@@ -47,8 +47,10 @@
 #include "private/qiconloader_p.h"
 #include "qpainter.h"
 #include "qfileinfo.h"
+#if QT_CONFIG(mimetype)
 #include <qmimedatabase.h>
 #include <qmimetype.h>
+#endif
 #include "qpixmapcache.h"
 #include "qvariant.h"
 #include "qcache.h"
@@ -313,9 +315,9 @@ QPixmap QPixmapIconEngine::pixmap(const QSize &size, QIcon::Mode mode, QIcon::St
                   % HexString<uint>(actualSize.height());
 
     if (mode == QIcon::Active) {
-        if (QPixmapCache::find(key % HexString<uint>(mode), pm))
+        if (QPixmapCache::find(key % HexString<uint>(mode), &pm))
             return pm; // horray
-        if (QPixmapCache::find(key % HexString<uint>(QIcon::Normal), pm)) {
+        if (QPixmapCache::find(key % HexString<uint>(QIcon::Normal), &pm)) {
             QPixmap active = pm;
             if (QGuiApplication *guiApp = qobject_cast<QGuiApplication *>(qApp))
                 active = static_cast<QGuiApplicationPrivate*>(QObjectPrivate::get(guiApp))->applyQIconStyleHelper(QIcon::Active, pm);
@@ -324,7 +326,7 @@ QPixmap QPixmapIconEngine::pixmap(const QSize &size, QIcon::Mode mode, QIcon::St
         }
     }
 
-    if (!QPixmapCache::find(key % HexString<uint>(mode), pm)) {
+    if (!QPixmapCache::find(key % HexString<uint>(mode), &pm)) {
         if (pm.size() != actualSize)
             pm = pm.scaled(actualSize, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
         if (pe->mode != mode && mode != QIcon::Normal) {
@@ -1078,11 +1080,12 @@ void QIcon::addFile(const QString &fileName, const QSize &size, Mode mode, State
     if (!d) {
 
         QFileInfo info(fileName);
-        QIconEngine *engine = iconEngineFromSuffix(fileName, info.suffix());
-#ifndef QT_NO_MIMETYPE
-        if (!engine)
-            engine = iconEngineFromSuffix(fileName, QMimeDatabase().mimeTypeForFile(info).preferredSuffix());
-#endif // !QT_NO_MIMETYPE
+        QString suffix = info.suffix();
+#if QT_CONFIG(mimetype)
+        if (suffix.isEmpty())
+            suffix = QMimeDatabase().mimeTypeForFile(info).preferredSuffix(); // determination from contents
+#endif // mimetype
+        QIconEngine *engine = iconEngineFromSuffix(fileName, suffix);
         d = new QIconPrivate(engine ? engine : new QPixmapIconEngine);
     }
 
@@ -1157,6 +1160,36 @@ QStringList QIcon::themeSearchPaths()
     return QIconLoader::instance()->themeSearchPaths();
 }
 
+/*!
+    \since 5.11
+
+    Returns the fallback search paths for icons.
+
+    The default value will depend on the platform.
+
+    \sa setFallbackSearchPaths(), themeSearchPaths()
+*/
+QStringList QIcon::fallbackSearchPaths()
+{
+    return QIconLoader::instance()->fallbackSearchPaths();
+}
+
+/*!
+    \since 5.11
+
+    Sets the fallback search paths for icons to \a paths.
+
+    \note To add some path without replacing existing ones:
+
+    \snippet code/src_gui_image_qicon.cpp 5
+
+    \sa fallbackSearchPaths(), setThemeSearchPaths()
+*/
+void QIcon::setFallbackSearchPaths(const QStringList &paths)
+{
+    QIconLoader::instance()->setFallbackSearchPaths(paths);
+}
+
 /*!
     \since 4.6
 
@@ -1164,7 +1197,7 @@ QStringList QIcon::themeSearchPaths()
 
     The \a name should correspond to a directory name in the
     themeSearchPath() containing an index.theme
-    file describing it's contents.
+    file describing its contents.
 
     \sa themeSearchPaths(), themeName()
 */
@@ -1189,6 +1222,37 @@ QString QIcon::themeName()
     return QIconLoader::instance()->themeName();
 }
 
+/*!
+    \since 5.12
+
+    Returns the name of the fallback icon theme.
+
+    On X11, if not set, the fallback icon theme depends on your desktop
+    settings. On other platforms it is not set by default.
+
+    \sa setFallbackThemeName(), themeName()
+*/
+QString QIcon::fallbackThemeName()
+{
+    return QIconLoader::instance()->fallbackThemeName();
+}
+
+/*!
+    \since 5.12
+
+    Sets the fallback icon theme to \a name.
+
+    The \a name should correspond to a directory name in the
+    themeSearchPath() containing an index.theme
+    file describing its contents.
+
+    \sa fallbackThemeName(), themeSearchPaths(), themeName()
+*/
+void QIcon::setFallbackThemeName(const QString &name)
+{
+    QIconLoader::instance()->setFallbackThemeName(name);
+}
+
 /*!
     \since 4.6
 
@@ -1216,7 +1280,10 @@ QString QIcon::themeName()
     the lookup. These caches can be generated using gtk-update-icon-cache:
     \l{https://developer.gnome.org/gtk3/stable/gtk-update-icon-cache.html}.
 
-    \sa themeName(), setThemeName(), themeSearchPaths()
+    \note If an icon can't be found in the current theme, then it will be
+    searched in fallbackSearchPaths() as an unthemed icon.
+
+    \sa themeName(), setThemeName(), themeSearchPaths(), fallbackSearchPaths()
 */
 QIcon QIcon::fromTheme(const QString &name)
 {
@@ -1456,7 +1523,7 @@ QDebug operator<<(QDebug dbg, const QIcon &i)
     foo@3x.png, then foo@2x, then fall back to foo.png if not found.
 
     \a sourceDevicePixelRatio will be set to the value of N if the argument is
-    a non-null pointer
+    not \nullptr
 */
 QString qt_findAtNxFile(const QString &baseFileName, qreal targetDevicePixelRatio,
                         qreal *sourceDevicePixelRatio)
